
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.1.26'
version = '1.1.26'
full_version = '1.1.26'
git_revision = '96431ad6609d8c6b4ea808090b460ddabc6154b2'
release = True

if not release:
    version = full_version
    short_version += ".dev"
